@@ -29,11 +29,24 @@
 
 #define DRUMKV1_LV2UI_URI DRUMKV1_LV2_PREFIX "ui"
 
-#ifdef CONFIG_LV2_UI_X11
+#if defined(CONFIG_LV2_UI_X11) || defined(CONFIG_LV2_UI_WINDOWS)
 #include <QWindow>
+#endif
+
+#ifdef CONFIG_LV2_UI_X11
 #define DRUMKV1_LV2UI_X11_URI DRUMKV1_LV2_PREFIX "ui_x11"
 #endif
 
+#ifdef CONFIG_LV2_UI_WINDOWS
+#include <windows.h>
+#define DRUMKV1_LV2UI_WINDOWS_URI DRUMKV1_LV2_PREFIX "ui_windows"
+
+// Polyfill for windows size (minimal suitable size)
+// Qt cannot determine the right window size on Windows.
+#define UI_WINDOWS_RECOMMENDED_WIDTH 1380
+#define UI_WINDOWS_RECOMMENDED_HEIGHT 650
+#endif
+
 #ifdef CONFIG_LV2_UI_EXTERNAL
 #include "lv2_external_ui.h"
 #define DRUMKV1_LV2UI_EXTERNAL_URI DRUMKV1_LV2_PREFIX "ui_external"
