@@ -1,7 +1,7 @@
 // drumkv1_sched.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,7 +22,8 @@
 #ifndef __drumkv1_sched_h
 #define __drumkv1_sched_h
 
-#include <stdint.h>
+#include <cstdint>
+
 
 // forward decls.
 class drumkv1;
