@@ -145,8 +145,8 @@ void drumkv1widget_jack::updateDirtyPreset ( bool bDirtyPreset )
 	drumkv1widget::updateDirtyPreset(bDirtyPreset);
 
 #ifdef CONFIG_NSM
-	if (m_pNsmClient && m_pNsmClient->is_active())
-		m_pNsmClient->dirty(true); // as far as NSM goes, we're always filthy!
+	if (m_pNsmClient && m_pNsmClient->is_active() && bDirtyPreset)
+		m_pNsmClient->dirty(true);
 #endif
 }
 
