@@ -1,7 +1,7 @@
 // drumkv1widget_preset.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -67,7 +67,7 @@ drumkv1widget_preset::drumkv1widget_preset ( QWidget *pParent )
 	m_pResetButton->setToolTip(tr("Reset Preset"));
 
 	QHBoxLayout *pHBoxLayout = new QHBoxLayout();
-	pHBoxLayout->setMargin(2);
+	pHBoxLayout->setContentsMargins(2, 2, 2, 2);
 	pHBoxLayout->setSpacing(4);
 	pHBoxLayout->addWidget(m_pNewButton);
 	pHBoxLayout->addWidget(m_pOpenButton);
@@ -92,7 +92,11 @@ drumkv1widget_preset::drumkv1widget_preset ( QWidget *pParent )
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(stabilizePreset()));
 	QObject::connect(m_pComboBox,
+	#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+		SIGNAL(textActivated(const QString&)),
+	#else
 		SIGNAL(activated(const QString&)),
+	#endif
 		SLOT(activatePreset(const QString&)));
 	QObject::connect(m_pSaveButton,
 		SIGNAL(clicked()),
@@ -235,7 +239,7 @@ void drumkv1widget_preset::openPreset (void)
 	const QString& sFilter = tr("Preset files (*.%1)").arg(sExt);
 
 	QWidget *pParentWidget = nullptr;
-	QFileDialog::Options options = 0;
+	QFileDialog::Options options;
 	if (pConfig->bDontUseNativeDialogs) {
 		options |= QFileDialog::DontUseNativeDialog;
 		pParentWidget = QWidget::window();
@@ -303,7 +307,7 @@ void drumkv1widget_preset::savePreset ( const QString& sPreset )
 		const QString& sTitle  = tr("Save Preset");
 		const QString& sFilter = tr("Preset files (*.%1)").arg(sExt);
 		QWidget *pParentWidget = nullptr;
-		QFileDialog::Options options = 0;
+		QFileDialog::Options options;
 		if (pConfig->bDontUseNativeDialogs) {
 			options |= QFileDialog::DontUseNativeDialog;
 			pParentWidget = QWidget::window();
